.TH kurly 1 "July 4, 2018" "kurly 1.2.2" "kurly Manual"

.SH NAME
kurly \- alternative to the popular program curl
.SH SYNOPSIS
.B kurly [options]
.I [URL]
.SH DESCRIPTION
.B kurly
is a tool to transfer data from a HTTP(S) server, similar to curl.

.SH OPTIONS
Options start with one or two dashes. Some options start with a single dash,
where the option string is a single character. Whereas if the options start with
a double dash, the option string can contain multiple characters.

Most options require a value, which should be specified next to them like this

	kurly -o
.B file
http://example.org/file

Unlike in curl, options cannot be grouped together with a single dash.

.B Example

curl can handle options like the following :

	curl -LOv https://httpbin.org/ip

which is equivalent to

	curl -L -O -v https://httpbin.org/ip

.B kurly expects options to be specified separately.

.IP "-A, --user-agent <value>"
This option is used to set the User Agent string header to the request. By default, "Kurly/1.0" is used.

.IP "-b, --cookie <data>"
This is option is used to pass the data as cookie data to the HTTP request. The data should be in the following format

.B		"NAME1=VALUE1; NAME2=VALUE2"

If no "=" is encountered in the data, the data is considered to be a filename which contains cookies. The cookies stored in the
file should be in the Netscape's cookie file format.

.IP "-C, --continue-at <offset>"
Continue option is used to continue/start the transfer from a given offset.
The offset is the number of bytes to be skipped from the beginning of the
remote source.
It requires an integer as a argument. If "-" is passed as an argument,
.B kurly
will try to guess the offset at which it should resume the transfer, by reading the file corresponding to the transfer.

.IP "-c, --cookie-jar <filename>"
Filename to which all the cookies had to be written after completed transfer. This program follows the old school
.B Netscape's cookie file format
\. As the same format is used in curl, the cookie files generated by curl can also be used in kurly.

.IP "--data-ascii <data>"
This is just an alias for \fI-d, --data\fP.

.IP "--data-binary <data>"
This posts the data passed exactly without any processing.

If the data with the character "@", the rest is considered as a filename.
Data is posted in a same way as \fI-d, --data\fP does, but the data is preserved.

.IP "--data-raw	<data>"
This posts data like \fI-d, --data\fP without the interpretation of the "@" character.

.IP "--data-urlencode <value>"

This posts data similar to \fI-d, --data\fP, but this performs URL-encoding conversion.

.IP "-d, --data <value>"

Sends a specific data in a POST request to the remote. This options submits a simple "application/x-www-form-urlencoded" form
to the remote server.

.IP "--expect100-timeout <value>"
Maximum time in seconds	for which kurly has to wait for a 100-continue response when a "Expects: 100-continue" header is set in the
request. By default the wait time is 1 second.

.IP "-F, --form <data>"
This option is used to POST multipart form data. This posts a "multipart/form-data" form.
This option enables \fBkurly\fP to upload binary files. The data passed as argument to this option should be in the form as follows

	"\fBNAME1=VALUE;[type=<mimetype>];[filename=<filename>]\fP"

If the VALUE starts with a "@", the rest is considered as a filename and the file is attached to the form data.
The type of the file and the filename can be explicitly set using the following type and filename attributes.
But they are not required as kurly can detect the mimetype and filename from the filename passed.

.IP "-H, --header <value>"
This option is used to set headers for the HTTP request. The header passed as an argument must be in the form \fB"HEADER_NAME: VALUE"\fP.
For setting the \fI"User-Agent"\fP header see \fI-A, --user-agent\fP option.

.IP "-h, --help"
Prints the usage. This lists all the usage and command line options than can be passed to the \fBkurly\fP command.

.IP "-I, --head"
Fetch only the headers. By this, \fBkurly\fP makes a HEAD request, for which the server responds with only the headers.

.IP "-k, --insecure"
This option allow kurly to continue even when the server connections are considered to be insecure.

.IP "-L, --location"
This option will make \fBkurly\fP to follow the redirects sent back by the server if any. The redirection location is specified in the
"\fBLocation\fP" of the response headers. A redirect is indicated by a \fI3XX\fP response code.

.IP "--max-redirs <value>"
Set the maximum number of redirection-followings allowed. By default kurly, uses 10 redirects.

.IP "-m, --max-time <value>"
Maximum time in seconds for which \fBkurly\fP can do an operation.

.IP "-o, --output <value>"
The filename to which the transfer response should be written to.

.IP "-O, --remote-name"
Write output to a local file named like the remote file we get. Only the filename part (basename equivalent) of the URL passed is used.

.IP "-R"
This option will make the timestamp of the current output file to be same as that of the remote file, if available.

.IP "-s, --silent"
This option will make \fBkurly\fP silent, so that no messages (progress meter or error output) is printed out to the stdout.

.IP "-T, --upload-file <value>"
This option is used to upload a file specified in the arguments to the remote.

.IP "-u, --user <value>"
This option is used to set the user authentication data to the current request. This encodes the passed string to base64 encoding and sets the
\fBAuthorization\fP header. Currently only the \fIBasic\fP authorization is implemented.

.IP "-v"
This option turns on verbose logging in \fBkurly\fP.

.IP "-V, --version"
Prints the version information of the program.

.IP "-X, --request <value>"
This option specifies which request method had to be used for the current request. Some common HTTP verbs (methods) used are
\fIGET\fP,\fIPOST\fP,\fIPUT\fP,\fIPATCH\fP,\fIDELETE\fP.

.SH AUTHORS / CONTRIBUTORS
David J Peacock is the main author, but the whole list of contributors is
found here \fIhttps://gitlab.com/davidjpeacock/kurly/graphs/master\fP.
.SH WWW
\fIhttps://gitlab.com/davidjpeacock/kurly\fP
.SH "SEE ALSO"
.BR wget (1),
.BR curl (1)
